<?php
namespace HCM\FPA\Repository;

use Doctrine\DBAL\Connection;
use Doctrine\ORM\EntityManager;
use HCM\Util\Repositories;

class ResumoContabilRepository {

    public function __construct(Connection $connection, EntityManager $entityManager) {
        $this->connection = $connection;
        $this->entityManager = $entityManager;

        $this->fpaResumoctbl = Repositories::FPA_RESUMOCTBL;
    }

    /**
     * Retorna as estruturas superiores do resumo contábil.
     *
     * @param string $dtocorrencia
     * @param int $nrorg
     * @param int $nrtipomoviment
     * @return int[]
     */
    public function getEstruturasSupResumo($dtocorrencia, $nrorg, $nrtipomoviment)
    {
        $sql = <<<SQL
SELECT r
  FROM $this->fpaResumoctbl r
 WHERE r.nrorg = :P_NRORG
   AND r.dtocorrencia = '$dtocorrencia'
   AND (r.nrtipomoviment = :P_NRTIPOMOVIMENT OR :P_NRTIPOMOVIMENT IS NULL)
SQL;
        $params = array(
            'P_NRORG' => $nrorg,
            'P_NRTIPOMOVIMENT' => $nrtipomoviment
        );

        $resultado = $this->entityManager->createQuery($sql)->execute($params);

        return $resultado;
    }
    
    
    public function getEstruturasSupResCont($dtocorrencia, $nrorg, $nrtipomoviment, $listaestrutsup = null) {
        $where = '';
        
        if($listaestrutsup)
            $where = " AND NRESTRUTURAMSUP IN ($listaestrutsup)";
        
        $query = $this->connection->prepare(
            "SELECT DISTINCT NRESTRUTURAMSUP
                    FROM FPA_RESUMOCTBL
                WHERE NRORG = :P_NRORG
                    AND DTOCORRENCIA = '$dtocorrencia'
                    AND (NRTIPOMOVIMENT = :P_NRTIPOMOVIMENT OR :P_NRTIPOMOVIMENT IS NULL)
                    $where
            "
        );

      $query->execute(
        array(
            'P_NRORG' => $nrorg,
            'P_NRTIPOMOVIMENT' => $nrtipomoviment
        )
      );
      

      return $query->fetchAll();
    }

    public function getProvisaoFerias($nrorg, $nrEstrutLegal, $dtContabil) {
        $sql = <<<SQL
            SELECT  
                INTLEGAL||';'||TO_CHAR(TO_DATE(:P_COMPETENCIA, 'DD/MM/YYYY'), 'MM/YYYY')||';Ferias;'||'Ferias;'||INTGEREN||';'||
                TRIM(TO_CHAR(SUM(NVL(DECODE( DIVISOR, 0, "'PROV'", "'PROV_'") / DECODE( DIVISOR, 0, 1, DIVISOR ) * DECODE( DIVISOR, 0, 1, 12 ), 0)), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
                TRIM(TO_CHAR(SUM(AVOS)*2.5, 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
                TRIM(TO_CHAR(ROUND((SUM( NVL("'PROV'", 0) + NVL("'PROV_'", 0) ) - NVL( SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ), 0 )),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(NVL( SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ), 0 ),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'
                ||TRIM(TO_CHAR(ROUND((MIN( NVL(-3*PAGA/4,  0))),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
				'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND((SUM( NVL("'PROV'", 0) + NVL("'PROV_'", 0) ) - MIN( NVL(3*PAGA/4,  0))),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||

                CHR(10)||INTLEGAL||';'||TO_CHAR(TO_DATE(:P_COMPETENCIA, 'DD/MM/YYYY'), 'MM/YYYY')||';Ferias;'||'1/3 Ferias;'||INTGEREN||';'||
                TRIM(TO_CHAR(SUM(NVL(DECODE( DIVISOR, 0, "'PROV'", "'PROV_'") / DECODE( DIVISOR, 0, 1, DIVISOR ) * DECODE( DIVISOR, 0, 1, 12 ), 0))/3, 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
                TRIM(TO_CHAR(SUM(AVOS)*2.5, 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
                TRIM(TO_CHAR(ROUND((SUM( NVL("'PROV'", 0) + NVL("'PROV_'", 0) ) - NVL( SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ), 0 )),2)/3, 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(NVL( SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ), 0 ),2)/3, 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'
                ||TRIM(TO_CHAR(ROUND((MIN( NVL(-3*PAGA/4,  0)/3)),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
				'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND((SUM( NVL("'PROV'", 0) + NVL("'PROV_'", 0) ) - MIN( NVL(3*PAGA/4,  0))),2)/3, 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||

                chr(10)||INTLEGAL||';'||TO_CHAR(TO_DATE(:P_COMPETENCIA, 'DD/MM/YYYY'), 'MM/YYYY')||';Ferias;'||'INSS;'||INTGEREN||';'||
                
                TRIM(TO_CHAR(ROUND(SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ) + SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) )/3,2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
                TRIM(TO_CHAR(MAX(CASE WHEN ROUND(NVL("'INSS_3604'", 0), 2)>0 THEN 33.30 ELSE 27.30 END), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
                TRIM(TO_CHAR(ROUND(NVL((SUM(DECODE( DIVISOR, 0, "'INSS'", "'INSS_'")) + SUM(6*NVL(DECODE( DIVISOR, 0, "'INSS'", "'INSS_'"), 0)/CASE WHEN INSS_PATRONAL >0 THEN  INSS_PATRONAL ELSE INSS_PATRONAL_ END))-(SUM(DECODE( DIVISOR, 0, "'INSS'", "'INSS_'")) + SUM(6*NVL(DECODE( DIVISOR, 0, "'INSS'", "'INSS_'"), 0)/CASE WHEN INSS_PATRONAL >0 THEN  INSS_PATRONAL ELSE INSS_PATRONAL_ END))/12,0),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
                '0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(NVL( NVL( (SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ) + SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) )/3)*MIN(CASE WHEN ROUND(NVL("'INSS_3604'", 0), 2)>0 THEN 0.333 ELSE 0.273 END), 0 ), 0 ),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'
                ||TRIM(TO_CHAR(ROUND((MIN( NVL(-PAGA,  0)*CASE WHEN ROUND(NVL("'INSS_3604'", 0), 2)>0 THEN 0.333 ELSE 0.273 END)),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
				'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(NVL( (SUM(DECODE( DIVISOR, 0, "'INSS'", "'INSS_'")) + SUM(6*NVL(DECODE( DIVISOR, 0, "'INSS'", "'INSS_'"), 0)/CASE WHEN INSS_PATRONAL >0 THEN  INSS_PATRONAL ELSE INSS_PATRONAL_ END))+(MIN( NVL(-PAGA,  0)*CASE WHEN ROUND(NVL("'INSS_3604'", 0), 2)>0 THEN 0.333 ELSE 0.273 END)), 0 ),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||

                chr(10)||INTLEGAL||';'||TO_CHAR(TO_DATE(:P_COMPETENCIA, 'DD/MM/YYYY'), 'MM/YYYY')||';Ferias;'||'FGTS;'||INTGEREN||';'||
                TRIM(TO_CHAR(ROUND(SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ) + SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) )/3,2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||'8,00'||';'||
                TRIM(TO_CHAR(ROUND(NVL((SUM(DECODE( DIVISOR, 0, "'FGTS'", "'FGTS_'")) - NVL( SUM( NVL( DECODE( DIVISOR, 0, "'FGTS'", "'FGTS_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ), 0 )),0),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'
                ||'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(NVL( SUM( NVL( DECODE( DIVISOR, 0, "'FGTS'", "'FGTS_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ), 0 ),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'
                ||TRIM(TO_CHAR(ROUND((MIN( NVL(-PAGA,  0)*0.08)),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
				'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(SUM( NVL("'FGTS'", 0) + NVL("'FGTS_'", 0) )+(MIN( NVL(-PAGA,  0)*0.08)),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';' REGISTRO,
                
                
                SUM(NVL(DECODE( DIVISOR, 0, "'PROV'", "'PROV_'") / DECODE( DIVISOR, 0, 1, DIVISOR ) * DECODE( DIVISOR, 0, 1, 12 ), 0)) SALARIO,
                SUM(ROUND(NVL("'INSS_3604'", 0), 2)) INSS_3604,      
                --DTFERIAS,
                SUM(AVOS) AVOS,
                SUM( NVL("'PROV'", 0) + NVL("'PROV_'", 0) )+(SUM( NVL("'PROV'", 0) + NVL("'PROV_'", 0) )/3) "'PROV'",
                (SUM(DECODE( DIVISOR, 0, "'INSS'", "'INSS_'")) + SUM(6*NVL(DECODE( DIVISOR, 0, "'INSS'", "'INSS_'"), 0)/CASE WHEN INSS_PATRONAL >0 THEN  INSS_PATRONAL ELSE INSS_PATRONAL_ END)) "'INSS'",
                SUM(DECODE( DIVISOR, 0, "'FGTS'", "'FGTS_'")) "'FGTS'",
                SUM( NVL("'VAR'",  0)) "'VAR'",
                SUM( NVL(3*PAGA/4,  0)) "'PAGO'",     
                NVL( SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ), 0 ) "'DIF_PROV'", /*Se o divisor não existir (null ou 0) este considera os eventos de vencidas em vez do proporcional*/
                NVL( (SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ) + SUM( NVL( DECODE( DIVISOR, 0, "'PROV'", "'PROV_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) )/3)*MIN(CASE WHEN ROUND(NVL("'INSS_3604'", 0), 2)>0 THEN 0.333 ELSE 0.273 END), 0 ) "'DIF_INSS'",
                NVL( SUM( NVL( DECODE( DIVISOR, 0, "'FGTS'", "'FGTS_'"), 0 ) / DECODE( DIVISOR, 0, 12, DIVISOR ) ), 0 ) "'DIF_FGTS'",
                NRLEGAL,
                RAZAOLEGAL,
                CNPJLEGAL,
                INTLEGAL,
                CNPJGEREN,
                INTGEREN
                FROM (SELECT
                        VM.NRVINCULOM      VINCULO,
                        VM.CDMATRICULA     MATRICULA,
                        VM.DSLIVROADMISSAO REGISTRO,
                        VM.NMVINCULOM      NOME,
                        VM.DTADMISSAOVINC  ADMISSAO,
                        ICF.NREVENTOM,
                        DECODE(ICF.NREVENTOM, 
											3604, 'INSS_3604',
						                    3270, 'PROV', /*Férias Vencidas*/
                                            3280, 'PROV_', /*Férias Proporcionais*/
                                            3310, 'INSS', /*Férias Vencidas*/
                                            3315, 'INSS', /*1/3 Férias Vencidas*/
                                            3320, 'INSS_', /*Férias Proporcionais*/
                                            3321, 'INSS_', /*1/3 Férias Proporcionais*/
                                            3350, 'FGTS', /*Férias Vencidas*/
                                            3355, 'FGTS', /*1/3 Férias Vencidas*/
                                            3360, 'FGTS_', /*Férias Proporcionais*/
                                            3361, 'FGTS_', /*1/3 Férias Proporcionais*/
                                            3272, 'VAR', /*Variável, médias*/
                                            3282, 'VAR', /*Variável, médias*/
                                            3271, 'PAGO'
                                            ) EVENTO,
                        DECODE(ICF.NREVENTOM, 3280, ICF.VRREFFOLHA,            	   /*em avos*/
                                            3270, ICF.VRREFFOLHA * 0.4, 0) AVOS, /*em dias, convertendo para avos*/
                        NVL( ( SELECT MIN(VRREFFOLHA) 
                                 FROM FPA_ITECALCFOLHA
                            WHERE NRORG          = VM.NRORG
                                AND NRVINCULOM     = VM.NRVINCULOM
                                AND NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                                AND NREVENTOM      = 3280 ), 0) DIVISOR, /*Se não existir referência de férias proporcionais este trata como '0' para atender lógica do decode no select acima*/
						( SELECT MIN(VRREFFOLHA) FROM FPA_ITECALCFOLHA
                           WHERE NRORG          = VM.NRORG
                            AND NRVINCULOM     = VM.NRVINCULOM
                            AND NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                            AND NREVENTOM      = 3310 ) INSS_PATRONAL,															
						( SELECT MIN(VRREFFOLHA) FROM FPA_ITECALCFOLHA
                           WHERE NRORG          = VM.NRORG
                            AND NRVINCULOM     = VM.NRVINCULOM
                            AND NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                            AND NREVENTOM      = 3320 ) INSS_PATRONAL_,															
							
						( SELECT SUM(VREVENTOFOLHA) 
						     FROM FPA_ITECALCFOLHA I
                           WHERE I.NRORG            = VM.NRORG
                             AND I.NRVINCULOM       = VM.NRVINCULOM
						     AND I.NREVENTOM    = 3010							 
							 AND I.DTOCORRENCIA = :P_COMPETENCIA
                             AND EXISTS (SELECT 1
							           FROM FPA_CALCULOFOLHA CFF
									  WHERE CFF.NRORG = VM.NRORG
									    AND CFF.NRCALCULOFOLHA = I.NRCALCULOFOLHA
									    AND CFF.NRTIPOMOVIMENT = 2
                                        AND CFF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                        AND CFF.DTOCORRENCIA   = :P_COMPETENCIA )) PAGA,																													
                        ICF.VREVENTOFOLHA  VALOR,
                        VH.NRESTRUTLEGAL   NRLEGAL,
                        VH.NRESTRUTGEREN   NRGEREN,
                        EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                        EHL.CDCNPJESTRUT   CNPJLEGAL,
                        NVL(
                            CASE
                                WHEN INSTR(EML.CDINTESTRUTURA, '.') > 0 THEN
                                    TO_NUMBER(SUBSTR(EML.CDINTESTRUTURA, 1, INSTR(EML.CDINTESTRUTURA, '.') - 1))
                                ELSE NULL
                            END,
                            EML.NRESTRUTURAM
                        ) AS INTLEGAL,
                        EML.DSURLLOGOESTRUTURA DSURLLOGO,
                        EHG.NMRAZSOCESTRUT RAZAOGEREN,
                        EHG.CDCNPJESTRUT   CNPJGEREN,
                        NVL(SUBSTR(EMG.CDINTESTRUTURA, INSTR(EMG.CDINTESTRUTURA, '.') + 1, INSTR(EMG.CDINTESTRUTURA, '.', -1) - INSTR(EMG.CDINTESTRUTURA, '.') - 1), EMG.NRESTRUTURAM) INTGEREN,
                        EMG.NRTPEVENTOCTBL,
                        VM.NRORG
                    FROM GPE_VINCULOM VM
                    JOIN GPE_VINCULOH VH ON VH.NRORG      = VM.NRORG
                                        AND VH.NRVINCULOM = VM.NRVINCULOM
                    /*ESTRUTURA LEGAL*/
                    LEFT JOIN ESTRUTURAM EML ON EML.NRORG        = VH.NRORG
                                            AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
                    LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = VH.NRORG
                                            AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                            AND EHL.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                                        WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                        AND NRORG        = VH.NRORG
                                                                        AND NRESTRUTURAM = EML.NRESTRUTURAM )
                    /*ESTRUTURA GERENCIAL*/
                    LEFT JOIN ESTRUTURAM EMG ON EMG.NRORG        = VH.NRORG
                                            AND EMG.NRESTRUTURAM = VH.NRESTRUTGEREN
                    LEFT JOIN ESTRUTURAH EHG ON EHG.NRORG        = VH.NRORG
                                            AND EHG.NRESTRUTURAM = EMG.NRESTRUTURAM
                                            AND EHG.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                                        WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                        AND NRORG        = VH.NRORG
                                                                        AND NRESTRUTURAM = EMG.NRESTRUTURAM )
                    /*CÁLCULO DE FOLHA*/
                    JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG       = VM.NRORG
                                            AND ICF.NRVINCULOM  = VM.NRVINCULOM
                    JOIN FPA_CALCULOFOLHA CF ON CF.NRORG            = VM.NRORG
                                            AND CF.NRCALCULOFOLHA   = ICF.NRCALCULOFOLHA
                                            AND CF.NRTIPOMOVIMENT = 1 /*Provisão Férias SELECT * FROM FPA_TIPOMOVIMENT*/
                                            AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                            AND CF.DTOCORRENCIA   = :P_COMPETENCIA
                    /*Eventos*/
                    JOIN FPA_EVENTOM EVM ON ( EVM.NRORG = 0 OR EVM.NRORG = CF.NRORG )
                                        AND EVM.NREVENTOM = ICF.NREVENTOM
                    JOIN FPA_EVENTOH EVH ON ( EVH.NRORG = 0 OR EVH.NRORG = EVM.NRORG )
                                        AND EVH.NREVENTOM = EVM.NREVENTOM
                                        AND EVH.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM FPA_EVENTOH
                                                                    WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                    AND ( NRORG = 0 OR NRORG = EVM.NRORG )
                                                                    AND NREVENTOM = EVM.NREVENTOM )
                    WHERE ( VM.NRORG          = :P_NRORG )
                        AND ICF.VRREFFOLHA>=0
                        AND ( VM.DTRESCISAOVINC > LAST_DAY(:P_COMPETENCIA) OR VM.DTRESCISAOVINC IS NULL ) /*VÍNCULOS NÃO DEMITIDOS, RESPEITANDO A COMPETÊNCIA*/
                        AND (INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',') > 0 OR :P_NRESTRUTLEGAL IS NULL) /*lista de estruturas*/
                        AND ICF.NREVENTOM IN ( 3270, 3275, 3280, 3281, 3310, 3315, 3320, 3321,
                        3350, 3355, 3360, 3361, 3272, 3282, 3271, 3604, 4030, 4050) /*SELEÇÃO DOS EVENTOS DE INTERESSE*/
                        /*VINCULO*/
                        AND VH.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC)
                                                FROM GPE_VINCULOH
                                                WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                    AND NRORG      = VM.NRORG
                                                    AND NRVINCULOM = VM.NRVINCULOM )
                        
                ) PIVOT ( SUM(VALOR) FOR EVENTO IN ('INSS_3604', 'PROV', 'PROV_', 'INSS', 'INSS_', 'FGTS', 'FGTS_', 'VAR' , 'PAGO'/*, 'DIF_PROV', 'DIF_INSS', 'DIF_FGTS'*/) ) PRI
                LEFT JOIN FPA_TPEVENTOCTBL TPE ON TPE.NRTPEVENTOCTBL = PRI.NRTPEVENTOCTBL
                                                    AND ( TPE.NRORG = PRI.NRORG
                                                    OR TPE.NRORG = :P_NRORG_PADRAO )
                GROUP BY NRLEGAL, NRGEREN, RAZAOLEGAL,
                CNPJLEGAL, INTLEGAL, RAZAOGEREN, CNPJGEREN, INTGEREN
                ORDER BY RAZAOLEGAL, RAZAOGEREN
SQL;

        $params = array(
            'P_NRORG'         => $nrorg,
            'P_NRORG_PADRAO'  => 0,
            'P_NRESTRUTLEGAL' => $nrEstrutLegal,
            'P_COMPETENCIA'   => $dtContabil,
            'P_MODALIDADECAL' => 1
        );
        
        return $this->connection->fetchAll($sql, $params);
    }

    public function getProvisao13($nrorg, $nrEstrutLegal, $dtContabil) {
        $sql = <<<SQL
            SELECT          /*Empresa;Competencia;Origem;Tipo;Local;Base;Dias;Anterior;Transferido;Ajuste;Provisao;Pagas;Adiantado;Indenizado;Saldo;*/
                INTLEGAL||';'||TO_CHAR(TO_DATE(:P_COMPETENCIA, 'DD/MM/YYYY'), 'MM/YYYY')||';13 Salario ;'||'Mensal;'||INTGEREN||';'||TRIM(TO_CHAR(SUM(ROUND(NVL("'SAL'", 0), 2)), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||TRIM(TO_CHAR(SUM(AVOS)*2.5, 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||TRIM(TO_CHAR(ROUND((SUM( NVL("'PROV'", 0) ) - NVL(SUM( NVL("'PROV'", 0) / DIVISOR ), 0 )),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(NVL(SUM( NVL("'PROV'", 0) / DIVISOR ), 0 ),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'
                ||'0,00;'||'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND((SUM( NVL("'PROV'", 0) ) - SUM( NVL("'PAGO'",  0))),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||

                chr(10)||INTLEGAL||';'||TO_CHAR(TO_DATE(:P_COMPETENCIA, 'DD/MM/YYYY'), 'MM/YYYY')||';13 Salario ;'||'INSS;'||INTGEREN||';'||
                TRIM(TO_CHAR(ROUND(0.08*SUM(ROUND(NVL("'SAL'" / DIVISOR * 12, 0), 2)),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
                TRIM(TO_CHAR(SUM(AVOS)*2.5, 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||
                TRIM(TO_CHAR(ROUND((SUM( NVL("'INSS'", 0) + CASE WHEN "'INSS_3604'" > 0 THEN 6*NVL("'INSS'", 0)/INSS_PATRONAL ELSE 0 END  ) - NVL(SUM( (NVL("'INSS'", 0) + CASE WHEN "'INSS_3604'" > 0 THEN 6*NVL("'INSS'", 0)/INSS_PATRONAL ELSE 0 END) / DIVISOR ), 0 )),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(NVL(SUM( NVL("'INSS'", 0) + CASE WHEN "'INSS_3604'" > 0 THEN 6*NVL("'INSS'", 0)/INSS_PATRONAL ELSE 0 END / DIVISOR ), 0 ),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||'0,00'||';0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(SUM( NVL("'INSS'", 0) + CASE WHEN "'INSS_3604'" > 0 THEN 6*NVL("'INSS'", 0)/INSS_PATRONAL ELSE 0 END ),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||

                chr(10)||INTLEGAL||';'||TO_CHAR(TO_DATE(:P_COMPETENCIA, 'DD/MM/YYYY'), 'MM/YYYY')||';13 Salario ;'||'FGTS;'||INTGEREN||';'||
                TRIM(TO_CHAR(ROUND(0.08*SUM(ROUND(NVL("'SAL'" / DIVISOR * 12, 0), 2)),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||'8,00'||';'||
                TRIM(TO_CHAR(ROUND((SUM( NVL("'FGTS'", 0) ) - NVL(SUM( NVL("'FGTS'", 0) / DIVISOR ), 0 )),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||'0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(NVL(SUM( NVL("'FGTS'", 0) / DIVISOR ), 0 ),2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';'||'0,00'||';0,00;'||'0,00;'||
                TRIM(TO_CHAR(ROUND(SUM(NVL("'FGTS'", 0)), 2), 'FM9999999990D00', 'NLS_NUMERIC_CHARACTERS='',.'''))||';' REGISTRO,
                SUM(ROUND(NVL("'SAL'" / DIVISOR * 12, 0), 2)) SALARIO,
                SUM(ROUND(NVL("'INSS_3604'", 0), 2)) INSS_3604,                                
                /*DIA,*/
                SUM(AVOS) AVOS,
                SUM( NVL("'PROV'", 0) ) "'PROV'",
                SUM( NVL("'INSS'", 0) + CASE WHEN "'INSS_3604'" > 0 THEN 6*NVL("'INSS'", 0)/INSS_PATRONAL ELSE 0 END) "'INSS'",
                SUM( NVL("'FGTS'", 0) ) "'FGTS'",
                SUM( NVL("'VAR'",  0)) "'VAR'",
                SUM( NVL("'PAGO'",  0)) "'PAGO'",   
                NVL(SUM( NVL("'PROV'", 0) / DIVISOR ), 0 ) "'DIF_PROV'",
                NVL(SUM( NVL("'INSS'", 0) + CASE WHEN "'INSS_3604'" > 0 THEN 6*NVL("'INSS'", 0)/INSS_PATRONAL ELSE 0 END / DIVISOR ), 0 ) "'DIF_INSS'",
                NVL(SUM( NVL("'FGTS'", 0) / DIVISOR ), 0 ) "'DIF_FGTS'",
                NRLEGAL,
                RAZAOLEGAL,
                CNPJLEGAL,
                INTLEGAL,
                CNPJGEREN,
                INTGEREN
                
            FROM (SELECT
                        VM.NRVINCULOM      VINCULO,
                        VM.CDMATRICULA     MATRICULA,
                        VM.DSLIVROADMISSAO REGISTRO,
                        VM.NMVINCULOM      NOME,
                        VM.DTADMISSAOVINC  ADMISSAO,
                        DECODE(ICF.NREVENTOM, 4070, 'SAL',
											  3604, 'INSS_3604',
                                              3290, 'PROV', /*Provisao 13º Salario*/
                                              3295, 'PROV', /*Provisao 13º Salario Avo Complementar*/
                                              3330, 'INSS', /*Provisao INSS 13º Salario*/
                                              3335, 'INSS', /*Provisao INSS 13º Salario sobre Avo Complementar*/
                                              3370, 'FGTS', /*Provisao FGTS 13º Salario*/
                                              3375, 'FGTS', /*Provisao FGTS 13º Salario sobre Avo Complementar*/
                                              3292, 'VAR', /*Provisao Media 13º Salario*/
                                              3291, 'PAGO'
                                            --3410, 'DIF_PROV', /*Provisao DIFP_13SAL_CONT*/
                                            --3415, 'DIF_PROV', /*Provisao DIFP_13SAL_CONT*/
                                            --3450, 'DIF_INSS', /*DIF1_13SAL_CONT*/
                                            --3455, 'DIF_INSS', /*DIF1_13SAL_CONT*/
                                            --3490, 'DIF_FGTS', /*DIF2_13SAL_CONT*/
                                            --3495, 'DIF_FGTS') /*DIF2_13SAL_CONT*/
                                            ) EVENTO,
                        DECODE(ICF.NREVENTOM, 3290, ICF.VRREFFOLHA,
                                            3295, ICF.VRREFFOLHA, 0) AVOS,
                        ( SELECT MIN(VRREFFOLHA) FROM FPA_ITECALCFOLHA
                        WHERE NRORG          = VM.NRORG
                            AND NRVINCULOM     = VM.NRVINCULOM
                            AND NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                            AND NREVENTOM      = 3290 ) DIVISOR,
                        ( SELECT MIN(VRREFFOLHA) FROM FPA_ITECALCFOLHA
                        WHERE NRORG          = VM.NRORG
                            AND NRVINCULOM     = VM.NRVINCULOM
                            AND NRCALCULOFOLHA = CF.NRCALCULOFOLHA
                            AND NREVENTOM      = 3330 ) INSS_PATRONAL,							
                        ICF.VREVENTOFOLHA  VALOR,
                        VH.NRESTRUTLEGAL   NRLEGAL,
                        VH.NRESTRUTGEREN   NRGEREN,
                        EHL.NMRAZSOCESTRUT RAZAOLEGAL,
                        EHL.CDCNPJESTRUT   CNPJLEGAL,
                        NVL(
                            CASE
                                WHEN INSTR(EML.CDINTESTRUTURA, '.') > 0 THEN
                                    TO_NUMBER(SUBSTR(EML.CDINTESTRUTURA, 1, INSTR(EML.CDINTESTRUTURA, '.') - 1))
                                ELSE NULL
                            END,
                            EML.NRESTRUTURAM
                        ) AS INTLEGAL,
                        EML.DSURLLOGOESTRUTURA DSURLLOGO,
                        EHG.NMRAZSOCESTRUT RAZAOGEREN,
                        EHG.CDCNPJESTRUT   CNPJGEREN,
                        NVL(SUBSTR(EMG.CDINTESTRUTURA, INSTR(EMG.CDINTESTRUTURA, '.') + 1, INSTR(EMG.CDINTESTRUTURA, '.', -1) - INSTR(EMG.CDINTESTRUTURA, '.') - 1), EMG.NRESTRUTURAM) INTGEREN,
                        VM.NRORG
                FROM GPE_VINCULOM VM
                JOIN GPE_VINCULOH VH ON VH.NRORG      = VM.NRORG
                                        AND VH.NRVINCULOM = VM.NRVINCULOM
                                        AND (INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',') > 0 OR :P_NRESTRUTLEGAL IS NULL) /*lista de estruturas*/
                                        AND VH.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM GPE_VINCULOH
                                                                    WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                    AND NRORG      = VM.NRORG
                                                                    AND NRVINCULOM = VM.NRVINCULOM )
            /*ESTRUTURA LEGAL*/
            LEFT JOIN ESTRUTURAM EML ON EML.NRORG        = VH.NRORG
                                            AND EML.NRESTRUTURAM = VH.NRESTRUTLEGAL
            LEFT JOIN ESTRUTURAH EHL ON EHL.NRORG        = VH.NRORG
                                            AND EHL.NRESTRUTURAM = EML.NRESTRUTURAM
                                            AND EHL.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                                        WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                        AND NRORG        = VH.NRORG
                                                                        AND NRESTRUTURAM = EML.NRESTRUTURAM )
            /*ESTRUTURA GERENCIAL*/
            LEFT JOIN ESTRUTURAM EMG ON EMG.NRORG        = VH.NRORG
                                            AND EMG.NRESTRUTURAM = VH.NRESTRUTGEREN
            LEFT JOIN ESTRUTURAH EHG ON EHG.NRORG        = VH.NRORG
                                            AND EHG.NRESTRUTURAM = EMG.NRESTRUTURAM
                                            AND EHG.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM ESTRUTURAH
                                                                        WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                                                                        AND NRORG        = VH.NRORG
                                                                        AND NRESTRUTURAM = EMG.NRESTRUTURAM )
            /*CÁLCULO DE FOLHA*/
            JOIN FPA_ITECALCFOLHA ICF ON ICF.NRORG       = VM.NRORG
                                            AND ICF.NRVINCULOM  = VM.NRVINCULOM
                                            AND ICF.NREVENTOM IN (3290, 3295, 3330, 3335, 3370, 3375, 3292, 3291, 3604, 4070) /*SELEÇÃO DOS EVENTOS DE INTERESSE*/
            JOIN FPA_CALCULOFOLHA CF ON CF.NRORG            = VM.NRORG  
                                            AND CF.NRCALCULOFOLHA   = ICF.NRCALCULOFOLHA
                                            AND CF.NRTIPOMOVIMENT = 1 /*Provisão 13º salário SELECT * FROM FPA_TIPOMOVIMENT*/
                                            AND CF.NRTPMODALIDCAL = :P_MODALIDADECAL
                                            AND CF.DTOCORRENCIA   = :P_COMPETENCIA
            
            JOIN FPA_EVENTOM EVM ON EVM.NREVENTOM      = ICF.NREVENTOM
            JOIN FPA_EVENTOH EVH ON EVH.NREVENTOM      = EVM.NREVENTOM
                                        AND EVH.DTMESCOMPETENC = ( SELECT MAX(DTMESCOMPETENC) FROM FPA_EVENTOH
                                                                    WHERE DTMESCOMPETENC <= :P_COMPETENCIA 
                                                                    AND NREVENTOM       = EVM.NREVENTOM )
                    --
                    WHERE ( VM.NRORG = :P_NRORG )
                        AND ( VM.DTRESCISAOVINC > LAST_DAY(:P_COMPETENCIA) OR VM.DTRESCISAOVINC IS NULL ) /*VÍNCULOS NÃO DEMITIDOS, RESPEITANDO A COMPETÊNCIA*/
                ) PIVOT ( SUM(VALOR) FOR EVENTO IN ('SAL', 'INSS_3604', 'PROV', 'INSS', 'FGTS', 'VAR', 'PAGO'/*, 'DIF_PROV', 'DIF_INSS', 'DIF_FGTS'*/) ) PRI
            /*alteração salarial*/			
            GROUP BY NRLEGAL, NRGEREN, RAZAOLEGAL, CNPJLEGAL, INTLEGAL, RAZAOGEREN, CNPJGEREN, INTGEREN
            ORDER BY RAZAOLEGAL, RAZAOGEREN
SQL;

        $params = array(
            'P_NRORG'         => $nrorg,
            'P_NRORG_PADRAO'  => 0,
            'P_NRESTRUTLEGAL' => $nrEstrutLegal,
            'P_COMPETENCIA'   => $dtContabil,
            'P_MODALIDADECAL' => 1
        );
        
        return $this->connection->fetchAll($sql, $params);
    }

    public function getFolha13Ferias($nrorg, $nrEstrutLegal, $dtContabil) {
        $sql = <<<SQL
            SELECT
                '0 ' || TO_CHAR(LAST_DAY(RC.DTOCORRENCIA), 'DDMMYYYY') ||
                ' ' || LPAD(REPLACE(TO_CHAR(MIN(DECODE(RC.IDTIPOLANC, 'D', NVL(RC.CDCONTCTBL, 0), 0))), ',', ''), 7, '0') ||
                ' ' || LPAD(REPLACE(TO_CHAR(MIN(DECODE(RC.IDTIPOLANC, 'C', NVL(RC.CDCONTCTBL, 0), 0))), ',', ''), 7, '0') ||
                ' ' || LPAD(REPLACE(TO_CHAR(SUM(NVL(ROUND(RC.VRLANCAMENTO, 2) * 100, 0))), ',', ''), 15, '0') ||
                ' ' || LPAD(NVL(MAX(RC.CDHISTPADR), 0), 4, '0') ||
                ' U 0001' AS REGISTRO,
                RC.NRESTRUTURAMSUP,
                RC.IDTIPOLANC,
                RC.CDCONTCTBL,
                RC.DTOCORRENCIA AS MES
            FROM FPA_RESUMOCTBL RC
            LEFT JOIN HISTPADR HP 
                ON HP.NRORG = RC.NRORG
                AND HP.CDHISTPADR = RC.CDHISTPADR
            LEFT JOIN CONTCTBL CCT 
                ON CCT.NRORG = RC.NRORG
                AND CCT.CDCONTCTBL = RC.CDCONTCTBL
                AND (CCT.IDTIPOCOME <> 'F' OR CCT.IDTIPOCOME IS NULL)
            LEFT JOIN CONTCORR CCR 
                ON CCR.NRORG = RC.NRORG
                AND CCR.CDCONTCTBL = CCT.CDCONTCTBL
            LEFT JOIN ESTRUTURAM EM 
                ON EM.NRORG = RC.NRORG
                AND EM.NRESTRUTURAM = RC.NRESTRUTURAM
            LEFT JOIN ESTRUTURAM EML 
                ON EML.NRORG = RC.NRORG
                AND (INSTR(',' || :P_NRESTRUTLEGAL || ',', ',' || EML.NRESTRUTURAM || ',') > 0 OR :P_NRESTRUTLEGAL IS NULL)
            WHERE RC.NRORG = :P_NRORG 
                AND RC.CDCONTCTBL IS NOT NULL 
                AND RC.DTOCORRENCIA = :P_COMPETENCIA
                AND (
                    INSTR(',' || :P_NRESTRUTLEGAL || ',', ',' || RC.NRESTRUTURAMSUP || ',') > 0 
                    OR (RC.NRESTRUTURAMSUP IS NULL AND :P_NRESTRUTLEGAL IS NULL)
                )
            GROUP BY RC.NRESTRUTURAMSUP,RC.IDTIPOLANC, RC.CDCONTCTBL, RC.DTOCORRENCIA
            ORDER BY 1
SQL;

        $params = array(
            'P_NRORG'         => $nrorg,
            'P_NRORG_PADRAO'  => 0,
            'P_NRESTRUTLEGAL' => $nrEstrutLegal,
            'P_COMPETENCIA'   => $dtContabil,
            'P_MODALIDADECAL' => 1
        );
        
        return $this->connection->fetchAll($sql, $params);
    }

    public function getFolha($nrorg, $nrEstrutLegal, $dtContabil) {
        $sql = <<<SQL
            SELECT 
                '1;' || TO_CHAR(LAST_DAY(:P_COMPETENCIA), 'DDMMYYYY') || ';' ||SUBSTR(
                    geh.cdintestrutura, 
                    INSTR(geh.cdintestrutura, '.') + 1, 
                    INSTR(geh.cdintestrutura, '.', -1) - INSTR(geh.cdintestrutura, '.') - 1
                )|| 
                ';00000;00000;' 
                || TO_CHAR(ROUND(SUM(I.VREVENTOFOLHA), 2), 'FM999999990D00', 'NLS_NUMERIC_CHARACTERS='', ''')
                || ';00000;RELACAO DE CALCULO REF ' || 
                TO_CHAR(LAST_DAY(:P_COMPETENCIA), 'MM/YYYY') || ';' || 
                NVL(
                    CASE
                        WHEN INSTR(ETH.cdintestrutura, '.') > 0 THEN
                            TO_NUMBER(SUBSTR(ETH.cdintestrutura, INSTR(ETH.cdintestrutura, '.') + 1))
                        ELSE NULL
                    END,
                    ETH.nrestruturam
                ) || 
                ';' || EH.NRORDIMPRESEVEN || 
                chr(10) || 
                '2;00000;' || 
                SUBSTR(
                    geh.cdintestrutura, 
                    INSTR(geh.cdintestrutura, '.') + 1, 
                    INSTR(geh.cdintestrutura, '.', -1) - INSTR(geh.cdintestrutura, '.') - 1
                ) || 
                ';'|| TO_CHAR(ROUND(SUM(I.VREVENTOFOLHA), 2), 'FM999999990D00', 'NLS_NUMERIC_CHARACTERS='', ''')
                || ';00000;00000;' || EH.NRORDIMPRESEVEN REGISTRO
            FROM FPA_ITECALCFOLHA I

            INNER JOIN FPA_CALCULOFOLHA C
                ON C.NRORG = I.NRORG
                AND C.NRCALCULOFOLHA = I.NRCALCULOFOLHA
                AND C.NRTIPOMOVIMENT = 1
                AND C.DTOCORRENCIA = :P_COMPETENCIA
                AND C.NRTPMODALIDCAL = :P_MODALIDADECAL 

            INNER JOIN FPA_EVENTOM EM ON (EM.NREVENTOM = I.NREVENTOM)

            INNER JOIN FPA_EVENTOH EH ON (EH.NREVENTOM = EM.NREVENTOM)
            INNER JOIN 
                (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, NREVENTOM
                FROM FPA_EVENTOH 
                WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                GROUP BY NREVENTOM
                ) EHATUAL 
                ON (EHATUAL.NREVENTOM = EH.NREVENTOM AND EHATUAL.DTMESCOMPETENC = EH.DTMESCOMPETENC)

            INNER JOIN GPE_VINCULOM VM 
                ON (I.NRORG = VM.NRORG AND I.NRVINCULOM = VM.NRVINCULOM)
            INNER JOIN GPE_VINCULOH VH 
                ON (VM.NRORG = VH.NRORG AND VM.NRVINCULOM = VH.NRVINCULOM
                    AND (INSTR(','||:P_NRESTRUTLEGAL||',', ','||VH.NRESTRUTLEGAL||',') > 0 OR :P_NRESTRUTLEGAL IS NULL)) /*lista de estruturas*/
            INNER JOIN 
                (SELECT MAX(DTMESCOMPETENC) DTMESCOMPETENC, 
                        NRVINCULOM,
                        NRORG
                FROM GPE_VINCULOH 
                WHERE DTMESCOMPETENC <= :P_COMPETENCIA
                GROUP BY NRVINCULOM, NRORG
                ) VHATUAL 
                ON (VHATUAL.NRVINCULOM = VH.NRVINCULOM AND VHATUAL.NRORG = VH.NRORG AND VHATUAL.DTMESCOMPETENC = VH.DTMESCOMPETENC)

            INNER JOIN ESTRUTURAM ETH 
                ON (VH.NRORG = ETH.NRORG AND VH.NRESTRUTLEGAL = ETH.NRESTRUTURAM)                
            INNER JOIN ESTRUTURAM GEH 
                ON (VH.NRORG = GEH.NRORG AND VH.NRESTRUTGEREN = GEH.NRESTRUTURAM)
            WHERE I.NRORG = :P_NRORG 
            GROUP BY 
                I.NREVENTOM,
                EH.NMEVENTOH,
                EM.IDTIPOEVENTO,
                ETH.cdintestrutura,
                --geh.cdintestrutura,
                SUBSTR(
                    geh.cdintestrutura, 
                    INSTR(geh.cdintestrutura, '.') + 1, 
                    INSTR(geh.cdintestrutura, '.', -1) - INSTR(geh.cdintestrutura, '.') - 1
                ),
                EH.NRORDIMPRESEVEN,
                NVL(
                    CASE
                        WHEN INSTR(ETH.cdintestrutura, '.') > 0 THEN
                            TO_NUMBER(SUBSTR(ETH.cdintestrutura, INSTR(ETH.cdintestrutura, '.') + 1))
                        ELSE NULL
                    END,
                    ETH.nrestruturam
                )
            ORDER BY EH.NRORDIMPRESEVEN, I.NREVENTOM

SQL;

        $params = array(
            'P_NRORG'         => $nrorg,
            'P_NRORG_PADRAO'  => 0,
            'P_NRESTRUTLEGAL' => $nrEstrutLegal,
            'P_COMPETENCIA'   => $dtContabil,
            'P_MODALIDADECAL' => 1,
        );
        
        return $this->connection->fetchAll($sql, $params);
    }

}