<?php

namespace HCM\Geral\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;
use HCM\Util\Repositories;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Error;
use HCM\Geral\Repository\RelatoriosHcmRepository;

class RelatoriosHcmService {
    
	const RPT_PONTO_DEMONSTRATIVO = 'ponto_demonstrativo';

    protected $entityManager;
    protected $hcmParameters;
    protected $relatoriosHcmRepository;
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters, RelatoriosHcmRepository $relatoriosHcmRepository) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->relatoriosHcmRepository    = $relatoriosHcmRepository;
    }
       
    public function rulesReports($parameters) {
        $nmReport = $parameters["P_NMREPORT"];

        switch ($nmReport) {
            case self::RPT_PONTO_DEMONSTRATIVO:
                return $this->rulesPontoDemonstrativo($parameters);
                break;
            
            default:
                return true;
                break;
        }
    }

    public function replaceMnemonicos($dsmensagem, $replaceMnemonico) {
        return strtr($dsmensagem, $replaceMnemonico);
    }

    // @todo melhorar modulariade e PRINCIPALOMENTE fazer um mapeamento de parâmetros para as rows!!!!!!
    public function getList_Sup1($row) {
        $nrorg          = $this->hcmParameters->getNrorgTrabalho();
        //$dtmescompetenc = $this->hcmParameters->getDtCompetencia();
        $nrocorrecal    = $this->hcmParameters->getOcorrenciaCalculo();
        $nrtpmodalidcal = $this->hcmParameters->getNrModalidadeCalculo();
        
        // @todo Usar o report para identificar qual bloco de lista será usado? Talvez usar uma variável na row como identificação.
        if (isset($row["mapping"]["resumo_movimento_hierarquia"])) {
            //$row = $row["resumo_movimento_hierarquia"][0];
            $dtmescompetenc   = $row["DTMESCOMPETENCIA"];
            $estruturalegal   = $row["NRESTRUTLEGAL"];
            $nrestrutsup      = $row["NRESTRUTSUPERIOR"];
            $ignoraocorr      = $row["NMOPCOES6"];
            $nrtipomoviment   = $row["NRTIPOMOVIMENT_RES"];
            $nrtipohierarqorg = $row["NRTIPOHIERARQORG"];
            $$incluir13       = $row["NMOPCOES3"];
            return $this->relatoriosHcmRepository->getLegSupGer(
                $nrorg, $dtmescompetenc, $estruturalegal, $nrestrutsup,
                $nrtipomoviment, $nrtpmodalidcal, $nrtipohierarqorg,
                $nrocorrecal, $incluir13, $ignoraocorr );
        }

        return null;
    }

    /**
     * Transforma um nome de arquivo "sujo" em um nome seguro para sistemas Linux,
     * removendo caracteres acentuados.
     *
     * Esta função converte o nome do arquivo para minúsculas, remove caracteres
     * não alfanuméricos (exceto espaços, underscores e hífens), substitui espaços
     * por underscores, remove underscores e hífens repetidos, remove underscores
     * e hífens do início e do fim do nome do arquivo e remove acentos.
     *
     * @param string $nomeArquivo O nome do arquivo "sujo".
     * @return string O nome do arquivo seguro para Linux.
     */
    public function getSafeName($nomeArquivo) {
        $nomeArquivo = strtolower($nomeArquivo);
        $nomeArquivo = $this->removeAcentos($nomeArquivo);
        // Remove caracteres não alfanuméricos, exceto espaços, underscores e hífens
        $nomeArquivo = preg_replace('/[^a-z0-9 _-]/', '', $nomeArquivo);
        $nomeArquivo = str_replace(' ', '_', $nomeArquivo);
        // Remove underscores e hífens repetidos
        $nomeArquivo = preg_replace('/[_ -]+/', '_', $nomeArquivo);
        // Remove underscores e hífens do início e do fim do nome do arquivo
        $nomeArquivo = trim($nomeArquivo, '_-');
    
        return $nomeArquivo;
    }
    
    /**
     * Remove acentos de caracteres.
     *
     * @param string $string A string com acentos.
     * @return string A string sem acentos.
     */
    public function removeAcentos($string) {
        return preg_replace(array(
        '/[áàãâä]/', '/[éèêë]/', '/[íìîï]/', '/[óòõôö]/', '/[úùûü]/', '/[ç]/',
        '/[ÁÀÃÂÄ]/', '/[ÉÈÊË]/', '/[ÍÌÎÏ]/', '/[ÓÒÕÔÖ]/', '/[ÚÙÛÜ]/', '/[Ç]/'
        ), array(
        'a', 'e', 'i', 'o', 'u', 'c',
        'A', 'E', 'I', 'O', 'U', 'C'
        ), $string);
    }

    private function rulesPontoDemonstrativo($parameters) {
    	$vinculo = $parameters["P_VINCULO"];
    	$nrorg   = $parameters["P_NRORG"];

    	// verifica parâmetro de controle de jornada da escala
    	$escala = \Folha\Entities\GpeEscalatrabh::getObjectsByWhere("NRESCALATRABM = ? AND NRORG = ? AND DTMESCOMPETENC <= ?", 
    	array($vinculo->historico->getNrescalatrabm(), $nrorg, $this->hcmParameters->getDtCompetencia()), "DTMESCOMPETENC ASC");
    	if (end($escala)->getIdnaocontrolajornada() == 'S')
			return false;

    	return true;
    	
    }
}