<?php
/**
 * Created by PhpStorm.
 * User: felipesantos
 * Date: 01/09/2016
 * Time: 16:25
 */

namespace HCM\VAB\Controllers;

use HCM\Util\Messages;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\DateUtil;
use HCM\VAB\Services\VabApuraBeneficioService;
use HCM\FPA\Services\IteCalcFolhaService;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Error;

class VabApuraBeneficioController extends Crud {

    protected $dataSourceName_getVabApuraBeneficio = 'getVabApuraBeneficio';

    protected $parameterBagColumns = array('P_NRORG', 'P_DTMESCOMPETENC', 'NRLOTEVINC_LIST', 'NRVINCULOM_LIST', 'NRESTRUTGEREN_FILTRO', 'NRESTRUTLEGAL_FILTRO');
    protected $toConvertInArray = array('NRVINCULOM_LIST', 'NRLOTEVINC_LIST', 'NRESTRUTGEREN_FILTRO', 'NRESTRUTLEGAL_FILTRO');

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, VabApuraBeneficioService $vabApuraBeneficioService, IteCalcFolhaService $iteCalcFolhaService){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->vabApuraBeneficioService = $vabApuraBeneficioService;
        $this->iteCalcFolhaService = $iteCalcFolhaService;
        parent::__construct($dataSourceManager);
    }
    
    public function getVabApuraBeneficio (DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName_getVabApuraBeneficio);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function setVabApuraBeneficio(DTO\Request\DataSet $request, DTO\Response $response)
    {
        try {
            $this->dataSourceName = "vab_apurabeneficio";
            foreach ($request->getDataSet()->getRows() as &$row) {
                $itensBeneficio = $this->iteCalcFolhaService->getItensBeneficioDirf(21, $row['NRCALCULOFOLHA'], $row['NRVINCULOM'], $row['NREVENTOM'], $row['VRAPURABENEFICIO'], $row['OLDVRAPURABENEFICIO'], $row['DTOCORRENCIA'], $row['NRORG']);
                $itensBeneficioModificados = $this->vabApuraBeneficioService->modificaArrayItens($itensBeneficio, $row['VRAPURABENEFICIO'], $row['OLDVRAPURABENEFICIO']);
                
                if(!empty($itensBeneficioModificados)){
                  $this->iteCalcFolhaService->editaItemCalcBeneficio($itensBeneficioModificados[0], $row['OLDVRAPURABENEFICIO'], $row['DTOCORRENCIA']);
                }
                
                parent::save($request, $response);
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteVabApuraBeneficio(DTO\Request\DataSet $request, DTO\Response $response)
    {
        try{
            /*sst_instrumentosavalriscos*/
            $this->dataSourceName = "vab_apurabeneficio";
            foreach ($request->getDataSet()->getRows() as &$row) {
                $itensBeneficio = $this->iteCalcFolhaService->getItensBeneficioDirf(21, $row['NRCALCULOFOLHA'], $row['NRVINCULOM'], $row['NREVENTOM'], $row['VRAPURABENEFICIO'], null, $row['DTOCORRENCIA'], $row['NRORG']);
                
                foreach($itensBeneficio as &$item){
                    $operacao = $this->vabApuraBeneficioService->verificaDelete($item, $row);
                    
                    if($operacao == 'SUBTRAI'){
                        $valorModificado = $item['VREVENTOFOLHA'] - $row['VRAPURABENEFICIO'];
                        $this->iteCalcFolhaService->editaItemCalcBeneficio($item, null, $row['DTOCORRENCIA'], $valorModificado);
                    }
                    
                    if($operacao == 'DELETE'){
                        $this->iteCalcFolhaService->deleteItemCalcBeneficio($item['NRITEMCALCFOLHA'], $item['NRORG']);
                    }
                }
                
                parent::delete($request, $response);
            }
        } catch(\Exception $e){
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    
    protected function convertArrayToString( $condition, $toConvertInArray ) {
        if ( in_array( $condition['columnName'], $toConvertInArray ) ) {
            if ( is_array( $condition['value'] ) ) {
                $condition['value'] = implode( ',', $condition['value'] );
                $condition['operator'] = '=';
            }
        }
        return $condition;
    }
    
    protected function populateParameterBag(FilterCriteria $filterCriteria) {
        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $condition = $this->convertArrayToString( $condition, $this->toConvertInArray );
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
}