<?php
namespace HCM\VAB\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\DateUtil;
use HCM\Util\HCMParameters;
use HCM\Util\Repositories;

class VabApuraBeneficioService {
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
    }
    
    /**
     * Modifies the value of items in an array based on new and original values.
     *
     * @param array $itensBeneficio An array of benefit items.
     * @param float $valorNovo The new value to apply.
     * @param float $valorOriginal The original value before modification.
     * @return array|null Returns the modified array or null if the input array is empty.
     */
    public function modificaArrayItens(array $itensBeneficio, float $valorNovo, float $valorOriginal): array{
        if(empty($itensBeneficio)){
            return [];
        }
        
        //Valor original é o valor antes da modificação na tela de dirf mensal - Apuração de beneficio
        //Valor Novo é após a modificação do valor do evento
        foreach ($itensBeneficio as &$item) {
            $this->atualizaItemValor($item, $valorNovo, $valorOriginal);
        }
        
        return $itensBeneficio;
    }
    
    private function atualizaItemValor(array &$item, float $valorNovo, float $valorOriginal): void {
        $divisor = $this->calculaDivisao($item['VREVENTOFOLHA'], $valorOriginal);
    
        if ($divisor <= 1) {
            // Se o divisor é menor ou igual a 1, substitui o valor do item diretamente
            $item['VREVENTOFOLHA'] = $valorNovo;
        } else {
            // Caso contrário, realiza o cálculo conforme a lógica
            $item['VREVENTOFOLHA'] = ($item['VREVENTOFOLHA'] / $divisor) + $valorNovo;
        }
    }
    
    public function calculaDivisao($valorItem, $valorOriginal){
        return $valorItem > $valorOriginal ? floor($valorItem / $valorOriginal) : 1;
    }
    
    public function verificaDelete($item, $row){
        if($item['VREVENTOFOLHA'] > $row['VRAPURABENEFICIO']){
            return 'SUBTRAI';
        }
        
        return 'DELETE';
    }
    
}  